/*
 *  Copyright (C) 1999, 2000 Bruno Pires Marinho
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _GTM_APPLET_H
#define _GTM_APPLET_H

/* Applet commands */
typedef enum {
    GTM_ACTION_NONE,
    GTM_ACTION_NEW_URL,
    GTM_ACTION_OPEN_GTM,
} GTMAppletCmd;

typedef struct 
{
    gchar *def_download_dir;
    gboolean addnew_changes_def_dl_dir;
    gboolean confirm_dnd_url;
    GTMAppletCmd binding_button1_click;
    gboolean disable_dl_dir;
} Properties;

/* The applet properties */
extern Properties gtm_applet_prop;

void gtm_open (void);

gboolean gtm_add_url (gchar *url, gchar *dir, gboolean disable_proxy,
                      gboolean disable_auto_dl);

#endif /* _GTM_APPLET_H */
